@@ -4,6 +4,7 @@ import re
 import json
 import time
 import glob
+import commentjson
 from json.decoder import JSONDecodeError
 from collections import OrderedDict
 from processor.helper.file.file_utils import exists_file, exists_dir, mkdir_path
@@ -90,7 +91,9 @@ def json_from_file(jsonfile, escape_chars=None, object_pairs_hook=OrderedDict):
                 with open(jsonfile, 'r', encoding='utf-8-sig') as infile:
                     file_data = infile.read()
             
-            jsondata = json.loads(file_data, object_pairs_hook=object_pairs_hook)
+            jsondata = commentjson.loads(file_data, object_pairs_hook=object_pairs_hook)
+
+            # jsondata = json.loads(file_data, object_pairs_hook=object_pairs_hook)
     except Exception as ex:
         logger.debug('Failed to load json from file: %s, exception: %s', jsonfile, ex)
     return jsondata
