@@ -14,6 +14,7 @@ from processor.templates.terraform.helper.function.terraform_functions import de
 from processor.templates.terraform.helper.expression.terraform_expressions import expression_list
 from processor.helper.json.json_utils import json_from_file, json_from_string
 from processor.helper.hcl.hcl_utils import hcl_to_json
+from processor.templates.terraform.helper.module_parser import ModuleParser
 
 logger = getlogger()
 
@@ -47,8 +48,11 @@ class TerraformTemplateParser(TemplateParser):
             "||" : "or",
             "None" : None
         }
+        self.replace_value_str = ["and", "or"]
         self.template_file_list = [self.template_file]
         self.parameter_file_list = self.parameter_file if self.parameter_file else []
+        self.connector_data = kwargs.get("connector_data", False)
+        self.exclude_directories = [".git"]
 
     def is_template_file(self, file_path):
         """
@@ -222,16 +226,22 @@ class TerraformTemplateParser(TemplateParser):
                                 self.module_params["module"][key][k] = processed_data
 
                         full_path_list = self.template_file.split("/")[:-1]
-                        full_path = ("/".join(full_path_list)).replace("//","/")
-                        module_file_path = ("%s/%s" % (full_path, value["source"])).replace("//","/")
+                        template_file_path = ("/".join(full_path_list)).replace("//","/")
+                        module_parser = ModuleParser(value["source"], template_file_path, connector_data=self.connector_data)
+                        module_file_path = module_parser.process_source()
 
-                        logger.info("Finding module : %s", value["source"])
+                        if not module_file_path:
+                            continue
+
+                        logger.info("Finding module : %s", module_file_path)
                         if exists_dir(module_file_path):
                             list_of_file = os.listdir(module_file_path)
 
                             template_file_path = ""
                             parameter_file_list = []
                             for entry in list_of_file:
+                                if any(exclude_dir in entry for exclude_dir in self.exclude_directories):
+                                    continue
                                 new_file_path = ('%s/%s' % (module_file_path, entry)).replace('//', '/')
                                 if exists_file(new_file_path):
                                     if self.is_template_file(new_file_path):
@@ -497,6 +507,12 @@ class TerraformTemplateParser(TemplateParser):
                 for param in found_parameters:
                 # for param in re.findall("(?:[^,()]|\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\))+", parameter_str.strip()):
                 # for param in parameter_str.strip().split(","):
+                    param_exmatch = re.search(r'(^[\'|\"]\${([^}]*)}[\'|\"]$)|(^\${([^}]*)}$)', param.strip(), re.I)
+                    if param_exmatch:
+                        match_values = re.search(r'(?<=\{).*(?=\})', param.strip(), re.I)
+                        if match_values:
+                            param = match_values.group(0)
+                
                     processed_param = self.process_resource("${" + param.strip() + "}", count)
                     if (isinstance(processed_param, str) and re.search(r'\${([^}]*)}', processed_param, re.I)):
                         process = False
@@ -528,20 +544,30 @@ class TerraformTemplateParser(TemplateParser):
 
                     parameter_str = m.group(0)
                     # params = re.findall(r"[a-zA-Z0-9.()\[\]_*\"]+|(?:(?![a-zA-Z0-9.()\[\]_*\"]).)+", parameter_str)
-                    params = re.findall(r"[a-zA-Z0-9.()\[\]_*\"\'\{\$\}]+|(?:(?![a-zA-Z0-9.()\[\]_*\"\'\{\$\}]).)+", parameter_str)
+                    params = re.findall(r"[a-zA-Z0-9.()\[\],-_*\"\'\{\$\}]+|(?:(?![a-zA-Z0-9.()\[\]_*\"\'\{\$\}]).)+", parameter_str)
 
                     if params and len(params) > 1:
                         new_parameter_list = []
+                        process_function = True
                         for param in params:
                             processed_param = self.process_resource("${" + param.strip() + "}")
-                            if isinstance(processed_param, str) and re.findall(r"[a-zA-Z]", processed_param):
+                            if isinstance(processed_param, str) and (re.findall(r".*\(.*\)", processed_param) or re.findall(r"\${([^}]*)}", processed_param)):
+                                process_function = False # parameter processing failed
+                                new_parameter_list.append("\"" + param + "\"")
+                            elif isinstance(processed_param, str) and re.findall(r"[a-zA-Z]", processed_param) and processed_param not in self.replace_value_str:
                                 new_parameter_list.append("\"" + processed_param + "\"")
                             elif isinstance(processed_param, str) and len(processed_param) == 0:
                                 new_parameter_list.append('""')
+                            elif processed_param is None and len(param.strip().split(".")) > 1:
+                                process_function = False # variable value not set in vars.tf file
+                                new_parameter_list.append("\"" + param + "\"")
                             else:
                                 new_parameter_list.append(str(processed_param))
 
-                        new_resource = func['method'](" ".join(new_parameter_list))
+                        if process_function:
+                            new_resource = func['method'](" ".join(new_parameter_list))
+                        else:
+                            new_resource = matched_str
                 else:
                     splited_list = matched_str.split(".") 
                     if len(splited_list) > 1:
